export const DATE_TAG_HEIGHT = 54;

export const GALLERY_ZOOM_GEAR_MIN = -2;

export const GALLERY_ZOOM_GEAR_MAX = 2;

export const GALLERY_DEFAULT_GRID_GAP = 2;

export const GALLERY_YEAR_MODE_GRID_GAP = 18;

export const GALLERY_DATE_MODE = {
  YEAR: 'year',
  MONTH: 'month',
  DAY: 'day',
  ALL: 'all',
};

export const STORAGE_GALLERY_DATE_MODE_KEY = 'gallery_date_mode';

export const STORAGE_GALLERY_ZOOM_GEAR_KEY = 'gallery_zoom_gear';
